@@ -55,7 +55,9 @@ __all__ = (
     "UserSortTypeType",
     "UserStatusTypeType",
     "UserTypeType",
+    "WorkDocsServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -131,6 +133,7 @@ UserFilterTypeType = Literal["ACTIVE_PENDING", "ALL"]
 UserSortTypeType = Literal["FULL_NAME", "STORAGE_LIMIT", "STORAGE_USED", "USER_NAME", "USER_STATUS"]
 UserStatusTypeType = Literal["ACTIVE", "INACTIVE", "PENDING"]
 UserTypeType = Literal["ADMIN", "MINIMALUSER", "POWERUSER", "USER", "WORKSPACESUSER"]
+WorkDocsServiceName = Literal["workdocs"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -162,6 +165,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -284,6 +288,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -432,6 +437,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "describe_activities",
     "describe_comments",
